@@ -75,7 +75,7 @@ EOT
         $input->setArgument('binary', $binaries[$binary]);
     }
 
-    protected function execute(InputInterface $input, OutputInterface $output)
+    protected function execute(InputInterface $input, OutputInterface $output): int
     {
         $composer = $this->requireComposer();
         if ($input->getOption('list') || null === $input->getArgument('binary')) {
