@@ -33,20 +33,8 @@ class ProxyManager
     /** @var ?self */
     private static $instance = null;
 
-    /** The following 3 properties can be removed after the transition period */
-
-    /** @var bool */
-    private $ignoreHttpsProxy = false;
-    /** @var bool */
-    private $isTransitional = false;
-    /** @var bool */
-    private $needsTransitionWarning = false;
-
     private function __construct()
     {
-        // this can be removed after the transition period
-        $this->isTransitional = true;
-
         try {
             $this->getProxyData();
         } catch (\RuntimeException $e) {
@@ -71,6 +59,11 @@ class ProxyManager
         self::$instance = null;
     }
 
+    public function hasProxy(): bool
+    {
+        return $this->httpProxy !== null || $this->httpsProxy !== null;
+    }
+
     /**
      * Returns a RequestProxy instance for the request url
      *
@@ -96,16 +89,6 @@ class ProxyManager
         return $proxy->toRequestProxy($scheme);
     }
 
-    /**
-     * Returns true if the user needs to set an https_proxy environment variable
-     *
-     * This method can be removed after the transition period
-     */
-    public function needsTransitionWarning(): bool
-    {
-        return $this->needsTransitionWarning;
-    }
-
     /**
      * Returns a ProxyItem if one is set for the scheme, otherwise null
      */
@@ -116,15 +99,6 @@ class ProxyManager
         }
 
         if ($scheme === 'https') {
-            // this can be removed after the transition period
-            if ($this->isTransitional && $this->httpsProxy === null) {
-                if ($this->httpProxy !== null && !$this->ignoreHttpsProxy) {
-                    $this->needsTransitionWarning = true;
-
-                    return $this->httpProxy;
-                }
-            }
-
             return $this->httpsProxy;
         }
 
@@ -179,11 +153,6 @@ class ProxyManager
                 if ($_SERVER[$name] !== '') {
                     return [$_SERVER[$name], $name];
                 }
-                // this can be removed after the transition period
-                if ($this->isTransitional && strtolower($name) === 'https_proxy') {
-                    $this->ignoreHttpsProxy = true;
-                    break;
-                }
             }
         }
 
