@@ -132,7 +132,7 @@ class InitCommandTest extends TestCase
     private function callParseAuthorString(InitCommand $command, string $string): array
     {
         $reflMethod = new \ReflectionMethod($command, 'parseAuthorString');
-        $reflMethod->setAccessible(true);
+        (\PHP_VERSION_ID < 80100) and $reflMethod->setAccessible(true);
 
         return $reflMethod->invoke($command, $string);
     }
