@@ -29,7 +29,7 @@ class ArchiveDownloaderTest extends TestCase
 
         $downloader = $this->getArchiveDownloaderMock();
         $method = new \ReflectionMethod($downloader, 'getFileName');
-        $method->setAccessible(true);
+        (\PHP_VERSION_ID < 80100) and $method->setAccessible(true);
 
         $this->config->expects($this->any())
             ->method('get')
@@ -49,7 +49,7 @@ class ArchiveDownloaderTest extends TestCase
 
         $downloader = $this->getArchiveDownloaderMock();
         $method = new \ReflectionMethod($downloader, 'processUrl');
-        $method->setAccessible(true);
+        (\PHP_VERSION_ID < 80100) and $method->setAccessible(true);
 
         $expected = 'https://github.com/composer/composer/zipball/master';
         $url = $method->invoke($downloader, $this->getMockBuilder('Composer\Package\PackageInterface')->getMock(), $expected);
@@ -65,7 +65,7 @@ class ArchiveDownloaderTest extends TestCase
 
         $downloader = $this->getArchiveDownloaderMock();
         $method = new \ReflectionMethod($downloader, 'processUrl');
-        $method->setAccessible(true);
+        (\PHP_VERSION_ID < 80100) and $method->setAccessible(true);
 
         $expected = 'https://github.com/composer/composer/archive/master.tar.gz';
         $url = $method->invoke($downloader, $this->getMockBuilder('Composer\Package\PackageInterface')->getMock(), $expected);
@@ -81,7 +81,7 @@ class ArchiveDownloaderTest extends TestCase
 
         $downloader = $this->getArchiveDownloaderMock();
         $method = new \ReflectionMethod($downloader, 'processUrl');
-        $method->setAccessible(true);
+        (\PHP_VERSION_ID < 80100) and $method->setAccessible(true);
 
         $expected = 'https://api.github.com/repos/composer/composer/zipball/master';
         $url = $method->invoke($downloader, $this->getMockBuilder('Composer\Package\PackageInterface')->getMock(), $expected);
@@ -100,7 +100,7 @@ class ArchiveDownloaderTest extends TestCase
 
         $downloader = $this->getArchiveDownloaderMock();
         $method = new \ReflectionMethod($downloader, 'processUrl');
-        $method->setAccessible(true);
+        (\PHP_VERSION_ID < 80100) and $method->setAccessible(true);
 
         $type = strpos($url, 'tar') ? 'tar' : 'zip';
         $expected = 'https://api.github.com/repos/composer/composer/'.$type.'ball/ref';
@@ -137,7 +137,7 @@ class ArchiveDownloaderTest extends TestCase
 
         $downloader = $this->getArchiveDownloaderMock();
         $method = new \ReflectionMethod($downloader, 'processUrl');
-        $method->setAccessible(true);
+        (\PHP_VERSION_ID < 80100) and $method->setAccessible(true);
 
         $url .= '.' . $extension;
         $expected = 'https://bitbucket.org/davereid/drush-virtualhost/get/ref.' . $extension;
