@@ -113,9 +113,9 @@ class LockerTest extends TestCase
                 'packages-dev' => [],
                 'aliases' => [],
                 'minimum-stability' => 'dev',
-                'stability-flags' => [],
-                'platform' => [],
-                'platform-dev' => [],
+                'stability-flags' => new \stdClass,
+                'platform' => new \stdClass,
+                'platform-dev' => new \stdClass,
                 'platform-overrides' => ['foo/bar' => '1.0'],
                 'prefer-stable' => false,
                 'prefer-lowest' => false,
