@@ -622,7 +622,7 @@ FUNDING;
     protected function setAttribute($object, string $attribute, $value): void
     {
         $attr = new \ReflectionProperty($object, $attribute);
-        $attr->setAccessible(true);
+        (\PHP_VERSION_ID < 80100) and $attr->setAccessible(true);
         $attr->setValue($object, $value);
     }
 }
